from __future__ import annotations

from sys import version_info

VERSION_MAJOR_MINOR = (version_info.major, version_info.minor)


__all__ = ["VERSION_MAJOR_MINOR"]
